==> breeze_website_builder_6.5.0.tar.gz: manage/plugins/lang/gallery/id.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Mengelola Parameter Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "mengelola Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Lebar");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Tinggi");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Gambar Lebar");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Gambar Tinggi");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Pertahankan Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Tampilkan Judul");
define('MANAGE_GALLERY_DISABLE_SORT', "Nonaktifkan Urut");
define('MANAGE_GALLERY_DELETE_IMAGE', "Hapus Gambar");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Simpan Urutkan Pesanan");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik &#39;Update&#39; untuk mempublikasikan <br /> gambar yang diupload.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Semua gambar telah diubah ukurannya dan pengaturan telah disimpan.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Terjadi kesalahan mengubah ukuran gambar atau menyimpan pengaturan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "gambar Anda (s) telah di-upload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Ada kesalahan saat mengunggah gambar Anda (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "File yang Anda mencoba untuk meng-upload bukan gambar.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "File yang Anda mencoba untuk meng-upload terlalu besar.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Judul telah disimpan.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Apakah Anda yakin ingin menghapus image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "gambar telah dihapus.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Ada kesalahan saat menghapus gambar.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Menyimpan parameter dan ukuran gambar, harap tunggu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Upload, harap tunggu ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Urutan belum disimpan. Apakah Anda ingin menyimpan urutan?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Urutan gambar semacam telah disimpan.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Ada menyimpan semacam gambar error.");
?>

==> breeze_website_builder_6.6.18.tar.gz: manage/plugins/lang/gallery/id.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright Silver Dolphin Solutions, LLC, Edward Lemmers, P.E.
// For licensing, see license.txt.
// Created: 3/1/2015	ELL

///////////////////////// Manage Gallery Parameters /////////////////////////
// Buttons:
define('MANAGE_GALLERY_HEADING', "Mengelola Parameter Lightbox Gallary");
define('MANAGE_GALLERY_MANAGE_GALLERY_BTN', "mengelola Gallery");
// Console Text:
define('MANAGE_GALLERY_FULL_WIDTH', "Full-Size Image Lebar");
define('MANAGE_GALLERY_FULL_HEIGHT', "Full-Size Image Tinggi");
define('MANAGE_GALLERY_THUMB_WIDTH', "Thumbnail Gambar Lebar");
define('MANAGE_GALLERY_THUMB_HEIGHT', "Thumbnail Gambar Tinggi");
define('MANAGE_GALLERY_PRESERVE_THUMB_ASPECT', "Pertahankan Thumb Aspect Ratio");
define('MANAGE_GALLERY_SHOW_TITLES', "Tampilkan Judul");
define('MANAGE_GALLERY_DISABLE_SORT', "Nonaktifkan Urut");
define('MANAGE_GALLERY_DELETE_IMAGE', "Hapus Gambar");
define('MANAGE_GALLERY_SAVE_SORT_ORDER', "Simpan Urutkan Pesanan");
define('MANAGE_GALLERY_PUBLISH_MSG', "Klik &#39;Update&#39; untuk mempublikasikan <br /> gambar yang diupload.");
// Popup Messages:
define('MANAGE_GALLERY_UPDATE_SUCCESS_MSG', "Semua gambar telah diubah ukurannya dan pengaturan telah disimpan.");
define('MANAGE_GALLERY_UPDATE_FAIL_ERR', "Terjadi kesalahan mengubah ukuran gambar atau menyimpan pengaturan.");
define('MANAGE_GALLERY_UPLOAD_SUCCESS_MSG', "gambar Anda (s) telah di-upload.");
define('MANAGE_GALLERY_UPLOAD_FAIL_ERR', "Ada kesalahan saat mengunggah gambar Anda (s).");
define('MANAGE_GALLERY_UPLOAD_NOT_IMAGE_ERR', "File yang Anda mencoba untuk meng-upload bukan gambar.");
define('MANAGE_GALLERY_UPLOAD_TOO_BIG_ERR', "File yang Anda mencoba untuk meng-upload terlalu besar.");
define('MANAGE_GALLERY_UPDATE_TITLE_SUCCESS_MSG', "Judul telah disimpan.");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_1_MSG', "Apakah Anda yakin ingin menghapus image");
define('MANAGE_GALLERY_DELETE_IMAGE_CONFIRM_2_MSG', "?");
define('MANAGE_GALLERY_DELETE_IMAGE_SUCCESS_MSG', "gambar telah dihapus.");
define('MANAGE_GALLERY_DELETE_IMAGE_FAIL_ERR', "Ada kesalahan saat menghapus gambar.");
define('MANAGE_GALLERY_SAVING_PARAMS_MSG', "Menyimpan parameter dan ukuran gambar, harap tunggu ...");
define('MANAGE_GALLERY_UPLOADING_IMAGES_MSG', "Upload, harap tunggu ...");
define('MANAGE_GALLERY_NOT_SAVED_MSG', "Urutan belum disimpan. Apakah Anda ingin menyimpan urutan?");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_SUCCESS_MSG', "Urutan gambar semacam telah disimpan.");
define('MANAGE_GALLERY_SAVE_SORT_ORDER_FAIL_ERR', "Ada menyimpan semacam gambar error.");
define('MANAGE_GALLERY_UPLOAD_BIGGER_THAN_ALLOWED_ERR', "File yang Anda coba unggah lebih besar dari pengaturan PHP &#39;upload_max_filesize&#39; atau &#39;post_max_size&#39;. Hubungi administrator sistem Anda untuk meningkatkan batasan ini.");
?>
